#!/bin/bash

# Script: upgrade.sh
# version: 2.0
# Author: Dominik Smolinski dsmolinski@torn.com.pl
#
# This version of upgrade script use rsync application to synchronize 
# jPALIO lib directory with version you need do have.
#
# Sample of use:
#
# Upgrade to 7.2.51
#   ./upgrade.sh 7.2.51
#
# Downgrade to 7.2.44 in two steps
#   ./upgrade.sh 0
#   ./upgrade.sh 7.2.44

export PATH=$PATH   #set PATH to rsync here
export RSYNC_PATH=rsync://jpalio.torn.com.pl/jpaliolib
export TIME=`date +%Y%m%d-%H%M`
export BACKUP=lib-$TIME
export VERSION=${1}

# Check rsync aplication avaliable
if rsync --version >/dev/null 2>&1 ; then
    :
else
    echo "Please install rsync package or set PATH property"
    exit -1
fi


# check for number of update version
[ $# == 0 ] && {
        VERSION=latest
}

# Check run directory
KATALOG=`pwd | sed -e 's/.*\///' `
[ "$KATALOG" = "jpalio-tools" ] && cd ..

# search for tomcat init script
INITSCRIPT=`ls -1 /etc/init.d/tomcat* 2>/dev/null | tail -1`
if [ "$INITSCRIPT" == "" ]
then
        INITSCRIPT="/opt/jpalio/jpalio"
fi

# backup by copy with archive and link files instead of copying options
cd ..
cp -al lib $BACKUP

# geting files by rsync
rsync -avz ${RSYNC_PATH}/lib-${VERSION}/* lib/
 
cd lib
# search to_remove file
if [ -f jpalio-tools/to_remove ]; then
    # remove deprecated files
    cat jpalio-tools/to_remove | while read PLIK ; do
        if [ "$PLIK" != "" ]; then
            rm -f $PLIK
        fi
    done
fi

# update tools.jar only if tools.jar in lib dir exist and JAVA_HOME is set
if [ -n $JAVA_HOME ] 
then
    TOOLS=$JAVA_HOME/lib/tools.jar
    if [ -f $TOOLS ]
    then
        if [ -L tools.jar ]
        then
            rm tools.jar
            ln -s $TOOLS 
        else
            if [ -f tools.jar ]
            then
                cp $TOOLS tools.jar
            fi
        fi
    fi
fi


# restart jPALIO
#if [ ! -f $INITSCRIPT ]
#then
#        echo "Nie znaleziono pliku do restartu jpalio."
#        echo "Zrestartuj jPalio ręcznie!"
#else
#        $INITSCRIPT restart
#fi
